@@ -260,8 +260,10 @@
     }
   }
   roc_prc <- cfunc(curvetype, c("ROC", "PRC"), 2)
-  basic_eval <- cfunc(curvetype, c("error", "accuracy", "specificity",
-                                   "sensitivity", "precision"), 5)
+  basic_eval <- cfunc(curvetype, c("score", "label", "error", "accuracy",
+                                   "specificity", "sensitivity", "precision",
+                                   "mcc", "fscore"),
+                      9)
 
   if (!roc_prc && !basic_eval) {
     stop("Invalid curvetype", call. = FALSE)
